@@ -1,11 +1,11 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "Anteckningar",
     "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
     "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
     "Error" : "Fel",
     "New note" : "Ny anteckning",
+    "Notes" : "Anteckningar",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
     "Settings" : "Inställningar",
     "Deleted {title}" : "Raderad {title}",
@@ -52,6 +52,7 @@ OC.L10N.register(
     "Note has unsaved changes" : "Note har osparade ändringar",
     "Subcategory" : "Underkategori",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
+    "_%n character_::_%n characters_" : ["%n tecken","%n tecken"],
     "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
     "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
     "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
@@ -67,7 +68,6 @@ OC.L10N.register(
     "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
     "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
     "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
-    "Updating note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
     "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
     "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
     "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
